#
# spec file for package gnome-tetravex
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-tetravex
Version:        3.38.2
Release:        bp155.3.10
Summary:        Tetravex Game for GNOME
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Puzzle
URL:            https://live.gnome.org/Tetravex
Source0:        https://download.gnome.org/sources/gnome-tetravex/3.38/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM 991ed9c9592047704efa436a34b84d392c9562d4.patch -- Reference of [GtkChild] fields is handled by GtkBuilder, type must be unowned
Patch0:         https://gitlab.gnome.org/GNOME/gnome-tetravex/-/commit/991ed9c9592047704efa436a34b84d392c9562d4.patch
# PATCH-FIX-UPSTREAM 20.patch -- Fix build with meson 0.60.0 and newer
Patch1:         https://gitlab.gnome.org/GNOME/gnome-tetravex/-/merge_requests/20.patch

BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.23
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0
BuildRequires:  pkgconfig(vapigen) >= 0.24

%description
Tetravex is a simple puzzle game in which pieces have numbers on each
side. The pieces must be positioned so that the same numbers touch
each other, during which you are being timed. The times are then
stored in a system-wide scoreboard.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%find_lang %{name}-gui %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc NEWS
%{_bindir}/%{name}
%{_datadir}/help/C/%{name}/
%{_datadir}/metainfo/org.gnome.Tetravex.appdata.xml
%{_datadir}/applications/org.gnome.Tetravex.desktop
%{_datadir}/dbus-1/services/org.gnome.Tetravex.service
%{_datadir}/glib-2.0/schemas/org.gnome.Tetravex.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man6/%{name}.6%{?ext_man}

%files lang -f %{name}.lang -f %{name}-gui.lang

%changelog
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 991ed9c9592047704efa436a34b84d392c9562d4.patch: Reference of
  [GtkChild] fields is handled by GtkBuilder, type must be unowned.
- Add 20.patch: Fix build with meson 0.60.0 and newer.
- Drop ancient gnotravex and gnotravex-lang Obsoletes, no longer
  needed, we can expect everyone to have upgraded by now.
- Stop marking enduser help files as docs. They are not
  documentation, and at the same time silence rpmlint.
* Mon Nov 23 2020 dimstar@opensuse.org
- Update to version 3.38.2:
  + Updated translations.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.91:
  + Some small additions to the main menu and the Shortcuts dialog,
    a shortcut for undoing all, and a new icon.
  + Updated translations.
* Mon Jul  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4:
  + Updated translations.
* Fri Jun  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Updated translations.
* Sat Apr 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Enlarge your Scores dialog.
  + Updated translations.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.36.0:
  + Updated translations.
* Mon Mar  2 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.35.92:
  + The F10 keyboard shortcut has been added, as a toggle for the
    hamburger button menu. Documentation for this shortcut will be
    added next cycle, no string changed.
  + Updated translations.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Fullscreen is better handled; some code improvements.
  + Updated translations.
* Fri Feb 14 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Updated translations.
- Changes from version 3.35.2:
  + The current game is being saved if the window is closed and a
    button was added to restore it (you can also directly restore,
    using the “--restore” command-line option).
  + The game can also be played with the keyboard (using arrows).
  + You can move all the tiles from one of the half-board using the
    mouse, by clicking on an empty border tile (even if this
    function is for now hidden).
  + Tetravex can for now be played in command-line, using the
    “--cli” option (see “--cli help” documentation.
  + GNOME Tetravex should be D-Bus activatable, what is more
    future-proof.
- Changes from version 3.35.1:
  + The most visible is the end of a game, where instead of having
    the Scores dialog popped-up, the ranking is overlaid on the
    now-empty right part of the board.
  + A default new theme.
  + Multiple themes are available (including the old one, under the
    name Nostalgia).
  + A new undo/redo functions, a great addition to the gameplay.
  + The puzzle will not anymore start already solved.
  + Scores are now displayed with a higher precision.
  + Updated translations.
* Fri Feb 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Updated translations.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + No changes.
* Tue Sep  3 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Mon Mar  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Update help for app menu changes.
  + Updated translations.
* Sun Feb 17 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Explicitly link with -lm.
  + Updated translations.
* Fri Feb  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Add tests to validate AppStream metadata and .desktop file.
  + Consistently use org.gnome.Tetravex app id. Note that this
    renames the icons, .desktop and AppStream metadata.
  + Miscellaneous cleanup.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Switch from autotools to meson.
  + Stop using intltool.
  + Follow GNOME 3.32 app menu recommendations.
  + Add Keyboard Shortcuts overlay.
  + Hide Keyboard Shortcuts section in app help.
  + Update AppStream metadata.
- Switch to meson buildsystem, add meson BuildRequires and macros.
- Drop intltool BuildRequires, no longer needed.
- Drop post(un) handling of glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un) and drop
  glib2_gsettings_schema_requires, no longer needed.
- Drop update-desktop-files BuildRequires and
  suse_update_desktop_file macro, no longer needed.
- Add fdupes BuildRequires and macro, remove duplicate files.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Aug 15 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Updated gettext head files.
* Mon Jul 18 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + No changes, version bump only.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Tue Sep 15 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + No changes, pure version bump.
* Wed Sep  2 2015 dimstar@opensuse.org
- Update to version 3.17.91:
  + icon: provide a symbolic variant of the app icon (bgo#747135).
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Updated translations.
* Mon Dec  1 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + gtk changes (accels, version bump, gresource).
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Added command line options.
  + Appdata Updates.
  + Updated requirements, general fixup.
  + Design Updates.
  + Updated translations.
* Wed Jul  2 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Require GTK+ 3.12, Vala 0.24.
  + Updated translations.
- Add pkgconfig(vapigen) BuildRequires: New dependency.
* Wed Jul  2 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Restore Ctrl+Arrow hotkeys for moving all pieces at once.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Combined Solve and new Game-Buttons.
  + Disable pause button when not useful.
* Mon Feb  3 2014 zaitor@opensuse.org
- Update to version 3.11.5:
  + Changed About dialog.
  + Fixed instructions.
  + Updated translations.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Updated About dialog.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Scores dialog: autoscroll to new score.
  + Move the fallback app menu into the headerbar, standardize
    Help/About/Quit.
  + Changed dependencies (Vala 0.22, GTK+ 3.10).
  + appdata: update homepage.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Check for *-validate before using it.
  + Run autoupdate.
  + Updated translations.
* Wed Oct 30 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + The UI has undergone a significant redesign.
  + Fix Pause button image getting out of sync after starting a new
    game.
  + Appdata is now translatable.
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + On new game make sure the pause button is set correctly.
  + Update button states after clicking the paused field.
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add an appdata file.
  + Updated translations.
* Wed Aug 21 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Reduce the width of the about dialog.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Mon Apr  8 2013 dimstar@opensuse.org
- Also obsolete -lang package.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
- Add icon_theme_post/postun calls for the new HighContrast icons.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
